@@ -1,11 +1,14 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
+from trytond.i18n import gettext
 from trytond.pool import PoolMeta, Pool
 from trytond.model import ModelView, Workflow, fields
 from trytond.wizard import Wizard, StateView, StateTransition, Button
 from trytond.pyson import Eval
 from trytond.transaction import Transaction
 
+from .exceptions import DepositError
+
 __all__ = ['Invoice', 'InvoiceLine',
     'DepositRecall', 'DepositRecallStart']
 
@@ -16,11 +19,6 @@ class Invoice(metaclass=PoolMeta):
     @classmethod
     def __setup__(cls):
         super(Invoice, cls).__setup__()
-        cls._error_messages.update({
-                'deposit_not_enough': (
-                    'The account "%(account)s" for party "%(party)s" '
-                    'has not enough deposit.'),
-                })
         cls._buttons.update({
                 'recall_deposit': {
                     'invisible': Eval('state') != 'draft',
@@ -96,17 +94,20 @@ class Invoice(metaclass=PoolMeta):
             for line in invoice.lines:
                 if line.type != 'line':
                     continue
-                if line.account.kind == 'deposit':
-                    if line.amount < 0:
+                if line.account.type.deposit:
+                    if ((invoice.type.endswith('invoice')
+                            and line.amount < 0)
+                            or (invoice.type.endswith('credit_note')
+                                and line.amount > 0)):
                         sign = 1 if invoice.type.startswith('in') else -1
                         to_check.add((invoice.party, line.account, sign))
 
         for party, account, sign in to_check:
             if not party.check_deposit(account, sign):
-                cls.raise_user_error('deposit_not_enough', {
-                        'account': account.rec_name,
-                        'party': party.rec_name,
-                        })
+                raise DepositError(
+                    gettext('account_deposit.msg_deposit_not_enough',
+                        account=account.rec_name,
+                        party=party.rec_name))
 
 
 class InvoiceLine(metaclass=PoolMeta):
@@ -115,7 +116,7 @@ class InvoiceLine(metaclass=PoolMeta):
     @classmethod
     def _account_domain(cls, type_):
         domain = super(InvoiceLine, cls)._account_domain(type_)
-        return domain + ['deposit']
+        return domain + [('type.deposit', '=', True)]
 
 
 class DepositRecall(Wizard):
@@ -151,7 +152,7 @@ class DepositRecallStart(ModelView):
     company = fields.Many2One('company.company', 'Company', readonly=True)
     account = fields.Many2One('account.account', 'Account', required=True,
         domain=[
-            ('kind', '=', 'deposit'),
+            ('type.deposit', '=', True),
             ('company', '=', Eval('company', -1)),
             ],
         depends=['company'])
